Struct ZwlrInputInhibitorV1
pub struct ZwlrInputInhibitorV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
inhibits input to other clients
While this resource exists, input to clients other than the owner of the inhibitor resource will not receive input events. Any client which previously had focus will receive a leave event and will not be given focus again. The client that owns this resource will receive all input events normally. The compositor will also disable all of its own input processing (such as keyboard shortcuts) while the inhibitor is active.
The compositor may continue to send input events to selected clients, such as an on-screen keyboard (via the input-method protocol).
This interface has no events.
Implementations
impl ZwlrInputInhibitorV1
impl ZwlrInputInhibitorV1
pub fn destroy(&self)
pub fn destroy(&self)
destroy the input inhibitor object
Destroy the inhibitor and allow other clients to receive input.